@@ -34,7 +34,7 @@ def log(text, *args, level=1):
     :param int level: 日志级别, 数字越高，打印信息越多，为0表示不打印日志。暂定级别有：0，1，2，3，4 可对应为logging的日志级别
     :return:
     """
-    if config.tracker_logging.get("Level"):
+    if config.get_logging_level() != "ERROR":
         text = text % args
         timestamp = time.strftime("%Y-%m-%d %H:%M:%S", time.localtime())
         sys.stdout.write("FAST: %s - %s\n" % (timestamp, text))
